package com.ruoyi.szxc.mapper;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcVisitRecard;

/**
 * 走访记录Mapper接口
 * 
 * @author hs
 * @date 2024-03-20
 */
public interface SzxcVisitRecardMapper 
{
    /**
     * 查询走访记录
     * 
     * @param id 走访记录主键
     * @return 走访记录
     */
    public SzxcVisitRecard selectSzxcVisitRecardById(Long id);

    /**
     * 查询走访记录列表
     * 
     * @param szxcVisitRecard 走访记录
     * @return 走访记录集合
     */
    public List<SzxcVisitRecard> selectSzxcVisitRecardList(SzxcVisitRecard szxcVisitRecard);

    /**
     * 新增走访记录
     * 
     * @param szxcVisitRecard 走访记录
     * @return 结果
     */
    public int insertSzxcVisitRecard(SzxcVisitRecard szxcVisitRecard);

    /**
     * 修改走访记录
     * 
     * @param szxcVisitRecard 走访记录
     * @return 结果
     */
    public int updateSzxcVisitRecard(SzxcVisitRecard szxcVisitRecard);

    /**
     * 删除走访记录
     * 
     * @param id 走访记录主键
     * @return 结果
     */
    public int deleteSzxcVisitRecardById(Long id);

    /**
     * 批量删除走访记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcVisitRecardByIds(Long[] ids);
}
